@@ -483,6 +483,16 @@ class TailsInstallerWindow(Gtk.ApplicationWindow):
                     'model':   info['model'],
                     'details': details
                 }
+                # Skip devices with non-removable bit enabled
+                if not info['removable']:
+                    message =_('The USB stick "%(pretty_name)s"'
+                               ' is configured as non-removable by its'
+                               ' manufacturer and Tails will fail to start on it.'
+                               ' Please try installing on a different model.') % {
+                               'pretty_name':  pretty_name
+                               }
+                    self.status(message)
+                    continue
                 # Skip too small devices, but inform the user
                 if not info['is_device_big_enough']:
                     message =_('The device "%(pretty_name)s"'
